@@ -1259,11 +1259,13 @@ public abstract class CMLUtil implements CMLConstants {
 			removeNonCMLAttributes(childElement);
 		}
 	}
-	/**
-<!DOCTYPE svg PUBLIC '-//W3C//DTD SVG 1.0//EN'
-          'http://www.w3.org/TR/2001/REC-SVG-20010904/DTD/svg10.dtd'>
-	 * @param s
-	 * @return
+	/** Removes the following content:
+	 *  <code>
+&lt;!DOCTYPE svg PUBLIC '-//W3C//DTD SVG 1.0//EN'
+          'http://www.w3.org/TR/2001/REC-SVG-20010904/DTD/svg10.dtd'&gt;
+     *  </code>
+	 * @param s String of the SVG document
+	 * @return  SVG document with problematic content removed
 	 * @throws IOException
 	 */
 	public static Document stripDTDAndOtherProblematicXMLHeadings(String s) throws IOException {
